@@ -268,15 +268,12 @@ class E6xDialect(default.DefaultDialect):
                 raise Exception("Got type of object {typ}".format(typ=type(connection)))
 
             client = cursor.connection
-            buffer = client.getColumns("default", table)
-            buffer = BytesIO(buffer)
-            dis = DataInputStream(buffer)
-            columns_info = get_query_columns_info(dis)
+            columns = client.getColumns("default", table)
             rows = list()
-            for i in columns_info:
+            for column in columns:
                 row = dict()
-                row["col_name"] = i.split(":")[0].lower()
-                row["data_type"] = i.split(":")[1].lower()
+                row["col_name"] = column.getFieldName()
+                row["data_type"] = column.getFieldType()
                 rows.append(row)
 
             return rows
